@@ -65,10 +65,6 @@ private Q_SLOTS:
     void nullSubtitle();
     void mediaInfo();
     void nullMediaInfo();
-    void linkPreviewer();
-    void nullLinkPreviewer();
-    void reactions();
-    void nullReactions();
     void hasReply();
     void nullHasReply();
     void replyId();
@@ -401,45 +397,6 @@ void EventHandlerTest::nullMediaInfo()
     QCOMPARE(noEventHandler.getMediaInfo(), QVariantMap());
 }
 
-void EventHandlerTest::linkPreviewer()
-{
-    auto event = room->messageEvents().at(2).get();
-    eventHandler.setEvent(event);
-
-    QCOMPARE(eventHandler.getLinkPreviewer()->url(), QUrl("https://kde.org"_ls));
-
-    event = room->messageEvents().at(0).get();
-    eventHandler.setEvent(event);
-
-    QCOMPARE(eventHandler.getLinkPreviewer(), nullptr);
-}
-
-void EventHandlerTest::nullLinkPreviewer()
-{
-    QTest::ignoreMessage(QtWarningMsg, "getLinkPreviewer called with m_room set to nullptr.");
-    QCOMPARE(emptyHandler.getLinkPreviewer(), nullptr);
-
-    QTest::ignoreMessage(QtWarningMsg, "getLinkPreviewer called with m_event set to nullptr.");
-    QCOMPARE(noEventHandler.getLinkPreviewer(), nullptr);
-}
-
-void EventHandlerTest::reactions()
-{
-    auto event = room->messageEvents().at(0).get();
-    eventHandler.setEvent(event);
-
-    QCOMPARE(eventHandler.getReactions()->rowCount(), 1);
-}
-
-void EventHandlerTest::nullReactions()
-{
-    QTest::ignoreMessage(QtWarningMsg, "getReactions called with m_room set to nullptr.");
-    QCOMPARE(emptyHandler.getReactions(), nullptr);
-
-    QTest::ignoreMessage(QtWarningMsg, "getReactions called with m_event set to nullptr.");
-    QCOMPARE(noEventHandler.getReactions(), nullptr);
-}
-
 void EventHandlerTest::hasReply()
 {
     auto event = room->messageEvents().at(5).get();
