@@ -9,23 +9,15 @@
 
 #include "neochatconnection.h"
 #include <Quotient/accountregistry.h>
-#include <Quotient/jobs/basejob.h>
 #include <Quotient/settings.h>
 
 #ifdef HAVE_KUNIFIEDPUSH
 #include <kunifiedpush/connector.h>
 #endif
 
-class NeoChatRoom;
 class TrayIcon;
 class QQuickTextDocument;
 
-namespace Quotient
-{
-class Room;
-class User;
-}
-
 namespace QKeychain
 {
 class ReadPasswordJob;
@@ -128,7 +120,6 @@ private:
 
     void loadSettings();
     void saveSettings() const;
-    QMap<Quotient::Room *, int> m_notificationCounts;
 
     Quotient::AccountRegistry m_accountRegistry;
     QStringList m_accountsLoading;
@@ -136,21 +127,12 @@ private:
 
 private Q_SLOTS:
     void invokeLogin();
-    void toggleWindow();
     void setQuitOnLastWindowClosed();
 
 Q_SIGNALS:
     void errorOccured(const QString &error, const QString &detail);
-    void syncDone();
     void connectionAdded(NeoChatConnection *connection);
     void connectionDropped(NeoChatConnection *connection);
-    void initiated();
-    void quitOnLastWindowClosedChanged();
-    void unreadCountChanged();
     void activeConnectionChanged();
-    void userConsentRequired(QUrl url);
     void accountsLoadingChanged();
-
-public Q_SLOTS:
-    void saveWindowGeometry();
 };
