@@ -4,15 +4,10 @@
 #include "neochatroom.h"
 
 #include <QFileInfo>
-#include <QGuiApplication>
-#include <QMetaObject>
-#include <QMimeDatabase>
-#include <QPalette>
-#include <QTemporaryFile>
-#include <QTextDocument>
-
 #include <QMediaMetaData>
 #include <QMediaPlayer>
+#include <QMimeDatabase>
+#include <QTemporaryFile>
 
 #include <Quotient/jobs/basejob.h>
 #include <Quotient/user.h>
@@ -35,13 +30,11 @@
 #include <Quotient/events/roommemberevent.h>
 #include <Quotient/events/roompowerlevelsevent.h>
 #include <Quotient/events/simplestateevents.h>
-#include <Quotient/events/stickerevent.h>
 #include <Quotient/jobs/downloadfilejob.h>
 #include <Quotient/qt_connection_util.h>
 
 #include "chatbarcache.h"
 #include "clipboard.h"
-#include "controller.h"
 #include "eventhandler.h"
 #include "events/joinrulesevent.h"
 #include "events/pollevent.h"
@@ -53,10 +46,9 @@
 #include "urlhelper.h"
 #include "utils.h"
 
-#include <KConfig>
-#include <KConfigGroup>
 #ifndef Q_OS_ANDROID
 #include <KIO/Job>
+#include <KIO/JobTracker>
 #endif
 #include <KJobTrackerInterface>
 #include <KLocalizedString>
@@ -108,16 +100,14 @@ NeoChatRoom::NeoChatRoom(Connection *connection, QString roomId, JoinState joinS
             return;
         }
         auto roomMemberEvent = currentState().get<RoomMemberEvent>(localUser()->id());
-        Q_ASSERT(roomMemberEvent);
-        const QString senderId = roomMemberEvent->senderId();
         QImage avatar_image;
-        if (!user(senderId)->avatarUrl(this).isEmpty()) {
-            avatar_image = user(senderId)->avatar(128, this);
+        if (roomMemberEvent && !user(roomMemberEvent->senderId())->avatarUrl(this).isEmpty()) {
+            avatar_image = user(roomMemberEvent->senderId())->avatar(128, this);
         } else {
             qWarning() << "using this room's avatar";
             avatar_image = avatar(128);
         }
-        NotificationsManager::instance().postInviteNotification(this, displayNameForHtml(), htmlSafeMemberName(senderId), avatar_image);
+        NotificationsManager::instance().postInviteNotification(this, displayName(), htmlSafeMemberName(roomMemberEvent->senderId()), avatar_image);
     });
     connect(this, &Room::changed, this, [this] {
         Q_EMIT canEncryptRoomChanged();
@@ -1727,15 +1717,26 @@ bool NeoChatRoom::canEncryptRoom() const
     return !usesEncryption() && canSendState("m.room.encryption"_ls);
 }
 
-PollHandler *NeoChatRoom::poll(const QString &eventId)
+static PollHandler *emptyPollHandler = new PollHandler;
+
+PollHandler *NeoChatRoom::poll(const QString &eventId) const
 {
+    if (auto pollHandler = m_polls[eventId]) {
+        return pollHandler;
+    }
+    return emptyPollHandler;
+}
+
+void NeoChatRoom::createPollHandler(const Quotient::PollStartEvent *event)
+{
+    if (event == nullptr) {
+        return;
+    }
+    auto eventId = event->id();
     if (!m_polls.contains(eventId)) {
-        auto handler = new PollHandler(this);
-        handler->setRoom(this);
-        handler->setPollStartEventId(eventId);
+        auto handler = new PollHandler(this, event);
         m_polls.insert(eventId, handler);
     }
-    return m_polls[eventId];
 }
 
 bool NeoChatRoom::downloadTempFile(const QString &eventId)
