@@ -13,6 +13,8 @@
 #include <QCoroTask>
 #include <Quotient/user.h>
 
+#include "enums/pushrule.h"
+#include "events/pollevent.h"
 #include "pollhandler.h"
 
 namespace Quotient
@@ -22,26 +24,6 @@ class User;
 
 class ChatBarCache;
 
-class PushNotificationState : public QObject
-{
-    Q_OBJECT
-    QML_ELEMENT
-    QML_UNCREATABLE("")
-
-public:
-    /**
-     * @brief Describes the push notification state for the room.
-     */
-    enum State {
-        Unknown, /**< The state has not yet been obtained from the server. */
-        Default, /**< The room follows the globally configured rules for the local user. */
-        Mute, /**< No notifications for messages in the room. */
-        MentionKeyword, /**< Notifications only for local user mentions and keywords. */
-        All, /**< Notifications for all messages. */
-    };
-    Q_ENUM(State)
-};
-
 /**
  * @class NeoChatRoom
  *
@@ -752,7 +734,14 @@ public:
      *
      * @sa PollHandler
      */
-    Q_INVOKABLE PollHandler *poll(const QString &eventId);
+    PollHandler *poll(const QString &eventId) const;
+
+    /**
+     * @brief Create a PollHandler object for the given event.
+     *
+     * @sa PollHandler
+     */
+    void createPollHandler(const Quotient::PollStartEvent *event);
 
     /**
      * @brief Get the full Json data for a given room account data event.
