@@ -56,6 +56,9 @@ void WindowController::saveGeometry()
 
 void WindowController::showAndRaiseWindow(const QString &startupId)
 {
+    if (m_window == nullptr) {
+        return;
+    }
     if (!m_window->isVisible()) {
         m_window->show();
         restoreGeometry();
@@ -102,4 +105,22 @@ void WindowController::setBlur(QQuickItem *item, bool blur)
 #endif
 }
 
+void WindowController::toggleWindow()
+{
+    if (m_window == nullptr) {
+        return;
+    }
+    if (window()->isVisible()) {
+        if (window()->windowStates() & Qt::WindowMinimized) {
+            window()->showNormal();
+            window()->requestActivate();
+        } else {
+            window()->close();
+        }
+    } else {
+        showAndRaiseWindow({});
+        window()->requestActivate();
+    }
+}
+
 #include "moc_windowcontroller.cpp"
